pitchtools.PitchClassObjectSet
==============================

.. abjad-lineage:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet

.. autoclass:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.intersection
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.isdisjoint
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.issubset
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.issuperset
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.union
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__cmp__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__rand__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__ror__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__rsub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__rxor__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__sub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObjectSet.PitchClassObjectSet.PitchClassObjectSet.__xor__
   :noindex:
